@@ -1,13 +1,8 @@
-import requests, os, getpass
+import requests, os, getpass, backoff
 import pandas as pd
 import matplotlib.pyplot as plt
 
-try:
-    from SciServer import SkyServer, Authentication
-except ModuleNotFoundError:
-    SkyServer = Authentication = None
-
-from timewise.general import main_logger, cache_dir
+from timewise.general import main_logger, cache_dir, backoff_hndlr
 
 
 logger = main_logger.getChild(__name__)
@@ -60,8 +55,9 @@ def get_sdss_credentials():
 
 
 def login_to_sciserver():
-
-    if isinstance(SkyServer, type(None)) or isinstance(Authentication, type(None)):
+    try:
+        from SciServer import Authentication
+    except ModuleNotFoundError:
         raise ModuleNotFoundError("Please install SciServer (https://github.com/sciserver/SciScript-Python) "
                                   "if you want to see SDSS cutouts!")
 
@@ -70,11 +66,21 @@ def login_to_sciserver():
     Authentication.login(uid, pw)
 
 
+@backoff.on_exception(
+        backoff.expo,
+        Exception,
+        max_tries=50,
+        on_backoff=backoff_hndlr
+    )
+def get_cutout(*args, **kwargs):
+    login_to_sciserver()
+    from SciServer import SkyServer
+    return SkyServer.getJpegImgCutout(*args, **kwargs)
+
+
 def plot_sdss_cutout(ra, dec, arcsec=20, arcsec_per_px=0.1, interactive=False, fn=None, title=None, save=False, ax=False,
                 height=2.5):
 
-    login_to_sciserver()
-
     ang_px = int(arcsec / arcsec_per_px)
     ang_deg = arcsec / 3600
 
@@ -84,7 +90,7 @@ def plot_sdss_cutout(ra, dec, arcsec=20, arcsec_per_px=0.1, interactive=False, f
         fig = plt.gcf()
 
     try:
-        im = SkyServer.getJpegImgCutout(ra, dec, scale=arcsec_per_px, height=ang_px, width=ang_px)
+        im = get_cutout(ra, dec, scale=arcsec_per_px, height=ang_px, width=ang_px)
         ax.imshow(im, origin='upper',
                   extent=([ra + ang_deg / 2, ra - ang_deg / 2,
                            dec - ang_deg / 2, dec + ang_deg / 2]),
@@ -119,9 +125,14 @@ def plot_sdss_cutout(ra, dec, arcsec=20, arcsec_per_px=0.1, interactive=False, f
 ###########################################################################################################
 
 
+###########################################################################################################
+#            START EXCESS VARIANCE UTILS            #
+#####################################################
+
 # calculate excess variance as done in section 7.3.4 of (Boller et al)
 # https://www.aanda.org/articles/aa/full_html/2016/04/aa25648-15/aa25648-15.html#S26
 
+
 def calc_Expectation(a):
      
     # variable prb is for probability
@@ -136,6 +147,7 @@ def calc_Expectation(a):
     # returning expectation as sum
     return float(sum)
 
+
 def get_excess_variance(y, y_err, mu):
     import numpy as np
     N = len(y)
@@ -152,4 +164,11 @@ def get_excess_variance(y, y_err, mu):
     term2 = np.sqrt((std_exp*2*F_var)/(N*mu))
     
     uncertainty = np.sqrt(term1**2 + term2**2)
-    return excess_variance, uncertainty
\ No newline at end of file
+    return excess_variance, uncertainty
+
+
+#####################################################
+#              END EXCESS VARIANCE UTILS            #
+###########################################################################################################
+
+
