@@ -81,7 +81,8 @@ class WISEDataDESYCluster(WiseDataByVisit):
                                     cluster_jobs_per_chunk=100, wait=5, remove_chunks=False,
                                     query_type='positional', overwrite=True,
                                     storage_directory=bigdata_dir,
-                                    skip_download=False):
+                                    skip_download=False,
+                                    skip_input=False):
         """
         An alternative to `get_photometric_data()` that uses the DESY cluster and is optimised for large datasets.
 
@@ -105,6 +106,10 @@ class WISEDataDESYCluster(WiseDataByVisit):
         :type overwrite: bool
         :param storage_directory: move binned files and raw data here after work is done
         :type storage_directory: str
+        :param skip_download: if True, assume data is already downloaded, only do binning in that case
+        :type skip_download: bool
+        :param skip_input: if True do not ask if data is correct before download
+        :type skip_input: bool
         """
 
         # --------------------- set defaults --------------------------- #
@@ -145,7 +150,8 @@ class WISEDataDESYCluster(WiseDataByVisit):
                      f"in {'magnitude' if mag else ''} {'flux' if flux else ''} "
                      f"from {tables}\nskipping download: {skip_download}")
 
-        input('Correct? [hit enter] ')
+        if not skip_input:
+            input('Correct? [hit enter] ')
 
         # --------------------------- set up cluster info --------------------------- #
 
@@ -679,8 +685,20 @@ class WISEDataDESYCluster(WiseDataByVisit):
     # END using cluster for downloading and binning        #
     # ----------------------------------------------------------------------------------- #
 
-    def plot_lc(self, parent_sample_idx, service='tap', plot_unbinned=False, plot_binned=True,
-                interactive=False, fn=None, ax=None, save=True, lum_key='flux_density', **kwargs):
+    def plot_lc(
+            self,
+            parent_sample_idx,
+            service='tap',
+            plot_unbinned=False,
+            plot_binned=True,
+            interactive=False,
+            fn=None,
+            ax=None,
+            save=True,
+            lum_key='flux_density',
+            load_from_bigdata_dir=False,
+            **kwargs
+    ):
         """Make a pretty plot of a lightcurve
 
         :param parent_sample_idx: The index in the parent sample of the lightcurve
@@ -699,6 +717,9 @@ class WISEDataDESYCluster(WiseDataByVisit):
         :param save: save the plot
         :type save: bool
         :param lum_key: the unit of luminosity to use in the plot, either of 'mag', 'flux_density' or 'luminosity'
+        :type lum_key: str
+        :param load_from_bigdata_dir: load from the the big data storage directory
+        :type load_from_bigdata_dir: bool
         :param kwargs: any additional kwargs will be passed on to `matplotlib.pyplot.subplots()`
         :return: the matplotlib.Figure and matplotlib.Axes if `interactive=True`
         """
@@ -714,7 +735,7 @@ class WISEDataDESYCluster(WiseDataByVisit):
         logger.debug(f"{wise_id} for {parent_sample_idx}")
 
         _chunk_number = self._get_chunk_number(parent_sample_index=parent_sample_idx)
-        lcs = self._load_lightcurves(service, chunk_number=_chunk_number)
+        lcs = self._load_lightcurves(service, chunk_number=_chunk_number, load_from_bigdata_dir=load_from_bigdata_dir)
         lc = pd.DataFrame.from_dict(lcs[f"{int(parent_sample_idx)}"])
 
         if plot_unbinned:
